use anyhow::Result;
use sdl3::{JoystickSubsystem, joystick::JoystickInstance};

pub struct Joystick {
    sdl2_joystick: sdl3::joystick::Joystick,

    name: String,
}

impl Joystick {
    pub fn new(joystick_subsystem: &JoystickSubsystem, instance: JoystickInstance) -> Result<Self> {
        let sdl2_joystick = joystick_subsystem.open(instance)?;

        Ok(Self {
            name: sdl2_joystick.name(),
            sdl2_joystick,
        })
    }

    pub fn id(&self) -> u32 {
        self.sdl2_joystick.instance_id()
    }

    pub fn name(&self) -> &str {
        &self.name
    }
}

impl std::fmt::Debug for Joystick {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        f.debug_struct("Joystick")
            .field("id", &self.id())
            .field("name", &self.name)
            .finish()
    }
}

unsafe impl Send for Joystick {}
unsafe impl Sync for Joystick {}
